﻿/*================================================
	nicoplayer.js
================================================*/

// クラスの作成,定義
var npsuper = Class.create();
npsuper.prototype =
{
	// ライブラリバージョン
	lib_version : "1.14",

	// デバッグモード
	// true : NicoPlayerに渡されたコマンド内容を情報ウィンドウに表示する
	debug : false, 


	// [initialize]
	initialize : function(){},

	//------------------------------------------------
	// NicoPlayerから呼び出されるメソッド
	//------------------------------------------------

	// [onChangeMediaState] メディアの再生状態が変更された後に呼び出される
	// 引数 state : 再生状態 ( "Stopped", "Paused", "Running", "" )
	onChangeMediaState : function( state )
	{
	},

	// [onReceiveComment] 最新コメントを受信した後に呼び出される
	// 引数 view    : 再生数
	//	comment : コメント数
	//      mylist  : マイリスト数
	// 最新コメントが見つからない場合や再生数などの情報に変化がない時でも呼び出されます
	onReceiveComment : function( view, comment, mylist )
	{
	},

	// [onChangePlayList] プレイリストが変更されたときに呼び出される
	onChangePlayList : function()
	{
	},

	// [onNotifyPostComment] コメントの投稿が完了したときに呼び出される
	// 引数 result : コメントの投稿結果を表す真理値
	onNotifyPostComment : function( result )
	{
	},

	// [onNotify] NicoPlayerから通知メッセージが送られたときに呼び出される(内部で使用)
	// 引数 message : 通知メッセージ
	onNotify : function( message )
	{
		switch( message )
		{
			case "postComment:result:true":
				this.onNotifyPostComment( true );
				break;
			case "postComment:result:false":
				this.onNotifyPostComment( false );
				break;
			default:
				break;
		}
	},

	//------------------------------------------------
	// NicoPlayerに処理をさせるメソッド
	//------------------------------------------------

	// [execApp] ファイルを実行
	// 引数 file : 実行するファイルパス
	//      arg  : ファイルに渡す引数
	// WinAPIのShellExecute()を使用しファイルを実行します
	// fileは""で括られます
	// argにパスを渡す場合はアプリケーションによって""で括る必要があります
	execApp : function( file, arg )
	{
		file = this.encloseString( file );
		this.execCmd( "exec " + file + " " + arg );
	},

	// [addMessage] 情報ウィンドウにメッセージを追加
	// 引数 msg : メッセージ
	// msgは""で括られます
	addMessage : function( msg )
	{
		msg = this.encloseString( msg );
		this.execCmd( "info msg=" + msg );
	},

	// [execCmd] NicoPlayerにコマンドを処理させる
	// 引数 cmd : コマンド文字列
	// コマンドは起動オプションで指定できる内容と同じです
	// NicoPlayerを操作する全てのメソッドから呼び出されます
	execCmd : function( cmd )
	{
		var url = "nicoplayer:" + cmd;
		if( cmd.match( "^get .*" ) )
		{
			url += " hwnd=VIDEOINFO";
		}
		url += " -inactive";
		if( this.debug )
		{
			url += " -echo";
		}
		window.navigate( url );
	},

	// [postComment] コメントを投稿する
	// 引数	comment : コメント
	//	command : コマンド
	//	vpos    : 動画上の位置(1/100秒)
	//	id      : 動画ID(省略すると現在再生中の動画が指定されます)
	postComment : function( comment, command, vpos, id )
	{
		// ダブルクォーテーションと改行をエスケープ
		comment.replace( /"/g, '\\"' );
		comment.replace( /\n/g, '\\n' );

		comment = this.encloseString( comment );
		command = this.encloseString( command );

		if( id == undefined )
		{
			id = "";
		}

		this.execCmd( "player -postcomment comment=" + comment + " command=" + command + " vpos=" + vpos + " id=" + id );
	},

	// ◆削除検討中のメソッドです
	// [readFile] ローカルのテキストファイルを読み込む
	// 引数 path : ファイルパス
	// 戻り値    : テキストデータ
	readFile : function( path )
	{
		path = this.encloseString( path );
		this.execCmd( "get -file path=" + path );
		return $('exchange').innerHTML.replace( /^<PRE>((.|\n)*)<\/PRE>$/, "$1" );	// 正規表現もっと良い方法ないかな..!?
	},

	// ◆削除検討中のメソッドです
	// [writeFile] ローカルのテキストファイルに書き込む
	// 引数 path : ファイルパス
	//      data : 書き込むテキストデータ
	writeFile : function( path, data )
	{
		path = this.encloseString( path );
		$('exchange').innerHTML = "<PRE>" + data + "</PRE>";
		this.execCmd( "other -writefile path=" + path );
	},

	//------------------------------------------------
	// NicoPlayerから情報を取得するメソッド
	//------------------------------------------------

	// [getVersion] NicoPlayerのバージョンを取得
	// 戻り値 : バージョンナンバー "x.xx"
	getVersion : function()
	{
		this.execCmd( "get -version" );
		return $('exchange').innerText;
	},

	// [getSoftDir] NicoPlayerがあるフォルダパスを取得
	// 戻り値 : ファイルパス
	getSoftDir : function()
	{
		this.execCmd( "get -softdir" );
		return $('exchange').innerText;
	},

	// [getPlayFile] 再生開始時に指定したファイルを取得
	// 戻り値 : ファイルパス
	getPlayFile : function()
	{
		this.execCmd( "get -playfile" );
		return $('exchange').innerText;
	},

	// [getMediaFile] 再生中のメディアファイルを取得
	// 戻り値 : ファイルパス
	getMediaFile : function()
	{
		this.execCmd( "get -mediafile" );
		return $('exchange').innerText;
	},

	// [getCommentFile] 再生中のコメントファイルを取得
	// 戻り値 : ファイルパス
	getCommentFile : function()
	{
		this.execCmd( "get -commentfile" );
		return $('exchange').innerText;
	},

	// [getInfoFile] 再生中のメディアファイルに対応する動画情報ファイルを取得
	// 戻り値 : ファイルパス
	getInfoFile : function()
	{
		this.execCmd( "get -infofile" );
		return $('exchange').innerText;
	},

	// [getTime] 現在の再生時間を取得
	// 戻り値 : 再生時間(ms)
	getTime : function()
	{
		this.execCmd( "get -time" );
		return $('exchange').innerText;
	},

	// [getLength] メディアの長さを取得
	// 戻り値 : メディアの長さ(ms)
	getLength : function()
	{
		this.execCmd( "get -length" );
		return $('exchange').innerText;
	},

	// [getMediaState] メディアの再生状態を取得
	// 戻り値 : 再生状態 ( "Stopped", "Paused", "Running", "" )
	// 空文字の場合はファイルが再生されていないことを表します
	getMediaState : function()
	{
		this.execCmd( "get -mediastate" );
		return $('exchange').innerText;
	},

	// [getPlayList] プレイリストのデータを取得
	// 戻り値 : プレイリストデータのオブジェクト配列
	// プロパティ name : ファイル名
	//            path : ファイルパス
	getPlayList : function()
	{
		this.execCmd( "get -playlist" );
		return eval( "(" + $('exchange').innerText + ")" );
	},

	// [getNavigateMode] ページ移動時の動作を取得
	// 戻り値 : ページ移動時の動作( "Inside" : 動画情報ウィンドウ内で開く ,  "Outside" : 外部ブラウザで開く )
	getNavigateMode : function()
	{
		this.execCmd( "get -navigatemode" );
		return $('exchange').innerText;
	},

	//------------------------------------------------
	// NicoPlayerの情報を設定するメソッド
	//------------------------------------------------

	// [setNavigateMode] ページ移動時の動作を設定
	// 引数 mode : ページ移動時の動作( "Inside" : 動画情報ウィンドウ内で開く ,  "Outside" : 外部ブラウザで開く )
	setNavigateMode : function( mode )
	{
		this.execCmd( "videoinfo -navigatemode mode=" + this.encloseString( mode ) );
	},

	//------------------------------------------------
	// 汎用
	//------------------------------------------------

	// [getThumbnailSource] サムネイルのソースを取得
	// 引数 idMovie       : 動画ID
	//      pathThumbnail : サムネイルパス
	// 戻り値 : サムネイルソース
	getThumbnailSource : function( idMovie, pathThumbnail )
	{
		var urlThumbnail = "http://tn-skr.smilevideo.jp/smile?i=" + idMovie;
		var srcThumbnail;
		if( pathThumbnail )
		{
			srcThumbnail = pathThumbnail;
		}
		else
		{
			srcThumbnail = urlThumbnail;
		}
		return srcThumbnail;
	},

	// [drawThumbnail] サムネイルを表示
	// 引数 srcThumbnail : サムネイルソース
	drawThumbnail : function( srcThumbnail )
	{
		document.write( '<img src="' + srcThumbnail + '" align="left" width="130" height="100" alt="サムネイル">' );
	},

	// [encloseString] 文字列を""で括る
	// 引数 str : 対象となる文字列
	// 戻り値 : ""で括られた文字列
	// 既に""で括られている場合は引数をそのまま返します
	encloseString : function( str )
	{
		if( str.match('^".*"$') == null )
		{
			str = '"' + str + '"';
		}
		return str;
	},

	dummyLastFunc: function(){}	// [dummyLastFunc]
};// クラス定義

var npbase = Class.create();
npbase.prototype = Object.extend( new npsuper, {} );

// クラスのインスタンス作成
var np = new npbase();

